@@ -20,7 +20,7 @@ class InvoiceAdmin(admin.ModelAdmin):
         'get_item_actions'
     ]
     list_display_links = ['type']
-    list_filter = ['type', 'creator', 'created']
+    list_filter = ['type', 'creator', 'created', 'customer']
     search_fields = ['id']
 
     def has_add_permission(self, request):
