@@ -9,7 +9,7 @@ CustomerSelect = function (params) {
     });
 
     function handleFieldChange() {
-        var customerId = $(this).val(),
+        var customerId = $field.val(),
             data = {customer: customerId};
 
         $field.prop('disabled', true);
@@ -23,6 +23,19 @@ CustomerSelect = function (params) {
         $(window).trigger('product-total-updated', response.total);
     }
 
+    function handleCustomerCreated(event, customer) {
+        var $option = $('<option />');
+
+        $option.text(customer.name);
+        $option.prop('value', customer.id);
+
+        $field.append($option);
+        $field.val(customer.id);
+
+        handleFieldChange();
+    }
+
     $field.on('change', handleFieldChange);
+    $(window).on('customer-created', handleCustomerCreated);
 
 };
