@@ -52,6 +52,10 @@ urlpatterns = [
          views.add_product,
          name='add-product'),
 
+    path('add-customer/',
+         views.add_customer,
+         name='add-customer'),
+
     path('products/', views.get_products, name='products')
 
 ]
