@@ -148,6 +148,36 @@ def add_product(request):
         status=status_code)
 
 
+@staff_member_required
+def add_customer(request):
+
+    form = forms.AddCustomerForm(request.POST or None)
+
+    status_code = 200
+
+    if request.method == 'POST':
+
+        if form.is_valid():
+
+            customer = form.save()
+
+            return JsonResponse({
+                'message': _('Customer added'),
+                'customer': {
+                    'id': customer.pk,
+                    'name': str(customer)
+                }
+            })
+        else:
+            status_code = 403
+
+    return render(
+        request,
+        'invoices/add-customer.html',
+        {'form': form, 'status_code': status_code},
+        status=status_code)
+
+
 @admin_render_view(template_name='invoices/print.html')
 def print_invoice(request, invoice_type, invoice_id):
     return  {
